@@ -4,14 +4,18 @@ from .values.text_val import TextVal
 from .values.null import NULL
 from .values.default import Default
 from .values.holder import Holder
+from .values.true import TRUE
+from .values.false import FALSE
 from .operators.comma import Comma
 
 
-class ValueList(Base, Number, TextVal, NULL, Default, Holder, Comma):
+class ValueList(Base, Number, TextVal, NULL, Default, Holder, TRUE, FALSE, Comma):
     reserved = {**Base.reserved, **Number.reserved, **TextVal.reserved,
-                **NULL.reserved, **Default.reserved, **Holder.reserved, **Comma.reserved}
+                **NULL.reserved, **Default.reserved, **Holder.reserved,
+                **TRUE.reserved, **FALSE.reserved, **Comma.reserved}
     tokens = Base.tokens + Number.tokens + TextVal.tokens + \
-        NULL.tokens + Default.tokens + Holder.tokens + Comma.tokens
+        NULL.tokens + Default.tokens + Holder.tokens + Comma.tokens + \
+        TRUE.tokens + FALSE.tokens
 
     # Tokens
 
@@ -21,6 +25,8 @@ class ValueList(Base, Number, TextVal, NULL, Default, Holder, Comma):
     @_rule('''value : DEFAULT
                     | NUMBER
                     | TEXTVAL
+                    | TRUE
+                    | FALSE
                     | NULL''')
     def p_value_items(self, p):
         p[0] = self.provider.new_record(p[1])
